@@ -114,7 +114,7 @@ class LogHandle(object):
             self.__gui_console = gui_obj
             self.__gui_console.log_setup(log_class=self)
         else:
-            self.__write_pipe.send({'command': 'gui_console', 'title': title, 'destroy': destroy, 'turn_off': turn_off})
+            self.__gui_console_set(title=title, destroy=destroy, turn_off=turn_off)
 
     def write_to_log(self, message, action='info', print_only=False):
         self.__write_to_log(message=message, action=action, print_only=print_only)
